pub struct CompiledExecutor { /* private fields */ }Expand description
Executes compiled action ASTs without any LLM calls
Implementations
Sourceimpl CompiledExecutor
impl CompiledExecutor
pub fn new() -> Self
pub fn with_variables(variables: HashMap<String, Value>) -> Self
Sourcepub fn with_dispatcher(self, dispatcher: CompiledToolDispatcher) -> Self
pub fn with_dispatcher(self, dispatcher: CompiledToolDispatcher) -> Self
Set a real tool dispatcher for bridging compiled action execution through sister bridges instead of simulating results.
Sourcepub fn execute(&mut self, compiled: &CompiledAction) -> ExecutionResult
pub fn execute(&mut self, compiled: &CompiledAction) -> ExecutionResult
Execute a compiled action. Returns zero tokens used.